import { BrowserPlugin } from '@snowplow/browser-tracker-core';
/** FocalMeter plugin configuration */
interface FocalMeterConfiguration {
    /** URL of the Kantar endpoint to send the requests to (including protocol) */
    kantarEndpoint: string;
    /** Whether to store information about the last submitted user ID in local storage to prevent sending it again on next load (defaults not to use local storage) */
    useLocalStorage?: boolean;
    /** Callback to process user ID before sending it in a request. This may be used to apply hashing to the value. */
    processUserId?: (userId: string) => string;
}
/**
 * The FocalMeter Plugin
 *
 * The plugin sends requests with the domain user ID to a Kantar endpoint used with the FocalMeter system.
 * A request is made when the first event with a new user ID is tracked.
 *
 * Call `enableFocalMeterIntegration()` to enable the integration with given configuration.
 */
declare function FocalMeterPlugin(): BrowserPlugin;
/**
 * Enables the integration with Kantar FocalMeter.
 *
 * @param configuration - Configuration with the URL endpoint to send requests to
 * @param trackers - The tracker identifiers which should have the context enabled
 */
declare function enableFocalMeterIntegration(configuration: FocalMeterConfiguration, trackers?: Array<string>): void;
export { FocalMeterConfiguration, FocalMeterPlugin, enableFocalMeterIntegration };
